@@ -40,10 +40,6 @@ class CustomAzureReader:
             byte_sequence = self.container_client.download_blob(file_name).readall()
             return json.loads(byte_sequence.decode("utf-8"))
         except ResourceNotFoundError as exception:
-            print(
-                "Could not find specified blob: {exception}".format(
-                    exception=str(exception)
-                )
-            )
+            print(f"Could not find specified blob: {exception}")
 
             return None
