@@ -15,6 +15,8 @@ from sdc_dp_helpers.base_writer import BaseWriter, CustomLocalJsonWriter
 
 
 class GAV3Writer:
+    """GAV3Writer Class"""
+
     def __init__(self, bucket, folder_path, profile_name=None):
         if profile_name is None:
             self.boto3_session = boto3.Session()
@@ -116,6 +118,6 @@ class CustomS3GZJsonWriter(CustomLocalJsonWriter, implements(BaseWriter)):
         """
         # generate a unix timestamp suffix for file
         suff = self.timestamp_suffix()
-        data_path = "{}_{}.json.gz".format(self.file_name, suff)
+        data_path = f"{self.file_name}_{suff}.json.gz"
         self.write_to_s3(self.data, data_path, mode="wb")
         self.data = []
