@@ -12,10 +12,9 @@ import boto3
 class CustomS3JsonWriter:
     """Class Extends Basic LocalGZJsonWriter"""
 
-    def __init__(self, bucket, file_path, profile_name=None):
+    def __init__(self, bucket, folder_path, profile_name=None):
         self.bucket = bucket
-        self.file_path = file_path
-        self.profile_name = profile_name
+        self.folder_path = folder_path
 
         if profile_name is None:
             self.boto3_session = boto3.Session()
@@ -30,10 +29,10 @@ class CustomS3JsonWriter:
             - pull from a specific date, we overwrite all that days data in the buckets.
             - this way, we ensure all data is original and in its most updated state.
         """
-        # dimension = json_data["dimension"]
+
         date = json_data["date"].replace("-", "")
         dataset = json_data["data"]
         business = json_data["business"]
-        key_path = f"{self.file_path}/{business}/{date}.json"
+        key_path = f"{self.folder_path}/{business}/{date}.json"
         print(f"Writing data to {key_path}.")
         self.s3_resource.Object(self.bucket, key_path).put(Body=json.dumps(dataset))
