@@ -41,8 +41,8 @@ class GooglePostmasterWriter(BaseWriter):
                                                                           data to be written
         """
         # confirm the payload keys are matching accurately with what is expected
-        if not {"date", "vertical", "brand", "data"}.issubset(set(payload.keys())):
-            raise KeyError("invalid payload expecting: date, vertical, brand and data.")
+        if not {"date", "brand", "data"}.issubset(set(payload.keys())):
+            raise KeyError("invalid payload expecting: date, brand and data.")
 
         if not isinstance(payload["data"], list):
             raise TypeError("invalid data passed: expected List[Dict[Any,Any]]")
