@@ -1,3 +1,4 @@
+# pylint: disable=inconsistent-return-statements, disable=too-few-public-methods,wrong-import-order
 """
     CUSTOM READERS CLASSES
         - Class which manages reader tasks like auth, requests, pagination
@@ -6,7 +7,6 @@ import os
 import socket
 
 from sailthru import SailthruClient
-
 from sdc_dp_helpers.api_utilities.date_managers import date_range, date_handler
 from sdc_dp_helpers.api_utilities.retry_managers import request_handler, retry_handler
 from sdc_dp_helpers.sailthru.config_magagers import get_config
@@ -56,16 +56,16 @@ class CustomSailThruReader:
         backoff_method=os.environ.get("REQUEST_BACKOFF_METHOD", 0.01),
     )
     def _get_stat(self, data, action="stats"):
+        """API call for stats"""
         response = self.sailthru_client.api_get(action=action, data=data)
         if response.is_ok():
             return response.get_body()
-        elif not response.is_ok():
+        if not response.is_ok():
             error = response.get_error()
-            message = "APIError:{}, Status Code:{}, Error Code:{}".format(
-                error.get_message(),
-                str(response.get_status_code()),
-                str(error.get_error_code()),
-            )
+            error_msg = str(error.get_message())
+            status_code = str(response.get_status_code())
+            error_code = str(error.get_error_code())
+            message = f"APIError:{error_msg}, Status Code:{status_code}, Error Code:{error_code}"
 
             if (
                 str(response.get_status_code()) != "404"
@@ -100,10 +100,10 @@ class CustomSailThruReader:
             )
 
             if action == "blast":
-                """
-                Retrieve information about a particular campaign or aggregated information
-                from all campaigns over a specified date range.
-                """
+                # """
+                # Retrieve information about a particular campaign or aggregated information
+                # from all campaigns over a specified date range.
+                # """
                 for _date in _date_range_list:
                     print(f"Gathering BLAST data for date: {_date}.")
                     stat_data = self._get_stat(
@@ -120,10 +120,10 @@ class CustomSailThruReader:
                         _data_set.append(stat_data)
 
             elif action == "list":
-                """
-                Retrieve information about your subscriber counts on all lists or a particular
-                list, as counted on a specified day’s snapshot, defaulting to the current day.
-                """
+                # """
+                # Retrieve information about your subscriber counts on all lists or a particular
+                # list, as counted on a specified day’s snapshot, defaulting to the current day.
+                # """
                 for _date in _date_range_list:
                     print(f"Gathering LIST data for date: {_date}.")
                     stat_data = self._get_stat(
@@ -138,10 +138,11 @@ class CustomSailThruReader:
                         _data_set.append(stat_data)
 
             elif action == "send":
-                """
-                Retrieve information about a particular triggered message or aggregated information
-                from triggered messages from that template over a specified date range.
-                """
+                # """
+                # Retrieve information about a particular triggered message
+                # or aggregated information from triggered messages from that
+                # template over a specified date range.
+                # """
                 _template_names = self._get_stat_templates()
                 print(f"Total templates: {len(_template_names)}.")
                 for _date in _date_range_list:
