@@ -10,7 +10,7 @@ import boto3
 class XMLWriter:
     """XMLWriter Class"""
 
-    def __init__(self, bucket, folder_path, file_name, profile_name=None):
+    def __init__(self, bucket, folder_path, profile_name=None):
         if profile_name is None:
             self.boto3_session = boto3.Session()
         else:
@@ -18,7 +18,6 @@ class XMLWriter:
         self.s3_resource = self.boto3_session.resource("s3")
         self.bucket = bucket
         self.folder_path = folder_path
-        self.file_name = file_name
 
     def write_to_s3(self, payload: list):
         """
@@ -26,6 +25,6 @@ class XMLWriter:
         """
         data = json.dumps(payload)
 
-        write_path = f"{self.folder_path}/{self.file_name}"
+        write_path = f"{self.folder_path}/data.json"
         print(f"Writing data to s3://{self.bucket}/{write_path}")
         self.s3_resource.Object(self.bucket, write_path).put(Body=data)
