@@ -1,9 +1,9 @@
 """CUSTOM INTERFACES FOR ZOHO RECRUIT ENDPOINTS"""
-# pylint: disable=broad-except,too-few-public-methods,too-many-arguments,arguments-differ, too-many-locals,abstract-method,unnecessary-dict-index-lookup,import-error
-# import sys
+
 # pylint: disable=broad-except,too-few-public-methods,too-many-arguments,arguments-differ, too-many-locals,abstract-method,unnecessary-dict-index-lookup,import-error
 import sys
-import time
+import os
+
 from datetime import datetime, timedelta
 from abc import ABC, abstractmethod
 from typing import Union, Any, List, Dict, Generator, Tuple
@@ -138,7 +138,11 @@ class CreateBulkJob(RequestHandler):
     """Creates Bulk Job"""
 
     @retry_handler(exceptions=APILimitError, total_tries=5, initial_wait=180)
-    @request_handler(wait=0, backoff_factor=0.01, backoff_method="random")
+    @request_handler(
+        wait=int(os.environ.get("API_WAIT_TIME", 30)),
+        backoff_factor=0.01,
+        backoff_method="random",
+    )
     def make_api_call(
         self, access_token: str, module: str, page: int, criteria: dict
     ) -> Tuple[Union[str, None], Union[str, None], Dict[Any, Any]]:
@@ -183,7 +187,11 @@ class CheckBulkJobStatus(RequestHandler):
     """Request Call to Check Bulk Job Status"""
 
     @retry_handler(exceptions=APILimitError, total_tries=5, initial_wait=180)
-    @request_handler(wait=0, backoff_factor=0.01, backoff_method="random")
+    @request_handler(
+        wait=int(os.environ.get("API_WAIT_TIME", 30)),
+        backoff_factor=0.01,
+        backoff_method="random",
+    )
     def make_api_call(
         self, access_token: str, job_id: str
     ) -> Tuple[Union[str, None], bool, Dict[Any, Any]]:
@@ -219,7 +227,11 @@ class BulkRequestHandler(RequestHandler):
     """Bulk Result Reader"""
 
     @retry_handler(exceptions=APILimitError, total_tries=5, initial_wait=180)
-    @request_handler(wait=0, backoff_factor=0.01, backoff_method="random")
+    @request_handler(
+        wait=int(os.environ.get("API_WAIT_TIME", 30)),
+        backoff_factor=0.01,
+        backoff_method="random",
+    )
     def make_api_call(self, access_token: str, job_id: str):
         """Download Bilk Data"""
         results = None
@@ -249,7 +261,11 @@ class AssessmentRequestHandler(RequestHandler):
     """Class for Making API Call"""
 
     @retry_handler(exceptions=APILimitError, total_tries=5, initial_wait=180)
-    @request_handler(wait=0, backoff_factor=0.01, backoff_method="random")
+    @request_handler(
+        wait=int(os.environ.get("API_WAIT_TIME", 30)),
+        backoff_factor=0.01,
+        backoff_method="random",
+    )
     def make_api_call(
         self,
         access_token: str,
@@ -299,7 +315,11 @@ class RecordsRequestHandler(RequestHandler):
     """Class for Making API Call"""
 
     @retry_handler(exceptions=APILimitError, total_tries=5, initial_wait=180)
-    @request_handler(wait=0, backoff_factor=0.01, backoff_method="random")
+    @request_handler(
+        wait=int(os.environ.get("API_WAIT_TIME", 30)),
+        backoff_factor=0.01,
+        backoff_method="random",
+    )
     def make_api_call(
         self,
         access_token: str,
@@ -350,7 +370,11 @@ class UsersRequestHandler(RequestHandler):
     """Class for Making API Call"""
 
     @retry_handler(exceptions=APILimitError, total_tries=5, initial_wait=180)
-    @request_handler(wait=0, backoff_factor=0.01, backoff_method="random")
+    @request_handler(
+        wait=int(os.environ.get("API_WAIT_TIME", 30)),
+        backoff_factor=0.01,
+        backoff_method="random",
+    )
     def make_api_call(
         self,
         access_token: str,
@@ -526,7 +550,7 @@ class RestAPICaller(ZohoRecruitAPI):
                 f"more_records {more_records} current_size {current_size}"
             )
 
-            self.get_access_token()
+            self.access_token = self.get_access_token()
 
             response = self.api_call(
                 api_call_handler,
@@ -561,7 +585,6 @@ class RestAPICaller(ZohoRecruitAPI):
                 result_array = []
                 current_size = 0
             page += 1
-            time.sleep(30)
 
 
 class RecordsEndpointHandler(RestAPICaller):
@@ -669,6 +692,12 @@ class BulkAPICaller(ZohoRecruitAPI):
         if module in ["Candidates"]:
             for item in criteria_group:
                 if item["api_name"] == "Modified_Time":
+                    new_item = {}
+                    new_item["api_name"] = "Last_Activity_Time"
+                    new_item.update(
+                        {key: value for key, value in item.items() if key != "api_name"}
+                    )
+                    group.append(new_item)
                     continue
                 if item["api_name"] == "Created_Time":
                     group.extend([item, item])
@@ -698,9 +727,9 @@ class BulkAPICaller(ZohoRecruitAPI):
         more_records: bool = False
         total_wait_time, wait_threshold = 0, 600
         while (state != "COMPLETED") or (total_wait_time > wait_threshold):
-            access_token: str = self.get_access_token()
+            self.access_token: str = self.get_access_token()
             state, more_records, results = self.check_status.make_api_call(
-                access_token=access_token, job_id=job_id
+                access_token=self.access_token, job_id=job_id
             )
             page, record_count = results.get("page"), results.get("count")
 
@@ -708,12 +737,6 @@ class BulkAPICaller(ZohoRecruitAPI):
                 proceed = True
                 break
 
-            print(
-                f"sleeping for 30 seconds waiting for bulk download...{total_wait_time}"
-            )
-            time.sleep(30)
-            total_wait_time += 30
-
         print(
             f"page: {page}, record_count: {record_count}, more_records: {more_records}"
         )
@@ -722,33 +745,30 @@ class BulkAPICaller(ZohoRecruitAPI):
     @staticmethod
     def parse_zip_file(response):
         """Parse the zip file"""
-        data_array: List[Dict[Any, Any]] = []
+        # data_array: List[Dict[Any, Any]] = []
         with ZipFile(BytesIO(response)) as zipfile:
             for file in zipfile.filelist:
                 with zipfile.open(file) as file_contents:
                     dict_reader = DictReader(
                         TextIOWrapper(file_contents, encoding="utf-8")
                     )
-                    data_array = list(dict_reader)
-                return data_array
+                    yield from dict_reader
 
     def api_call(self, api_call_handler: RequestHandler, **kwargs):
         """Makes api call"""
         job_id: str = kwargs["job_id"]
-        results: List[Dict[Any, Any]] = []
         download_status = self.wait_for_download(job_id=job_id)
         if download_status[0] is True and download_status[1] > 0:
+            self.access_token = self.get_access_token()
             response = api_call_handler.make_api_call(
                 access_token=self.access_token, job_id=job_id
             )
-            results = self.parse_zip_file(response)
-        return results
+            yield from self.parse_zip_file(response)
 
     def paginate(self, api_call_handler: RequestHandler, module, configs, criteria):
         """Paginator Function Through the Pages"""
 
         result_array = []
-        avg_record_size: int = 0
         current_size: int = 0
         more_records = True
         self.file_size_limit = configs.get("file_size_limit", 5242880)
@@ -761,7 +781,6 @@ class BulkAPICaller(ZohoRecruitAPI):
             )
 
             print(f"bulk_job status: {status} and job_id : {job_id}")
-            time.sleep(5)
             state, more_records, _ = self.check_status.make_api_call(
                 self.access_token, job_id
             )
@@ -771,27 +790,25 @@ class BulkAPICaller(ZohoRecruitAPI):
             page += 1
 
         for job_id, values in self.jobs.items():
-            avg_record_size: int = 0
             if values["downloaded"] is True:
                 continue
             results = self.api_call(api_call_handler, job_id=job_id)
             if not results:
                 print(f"No data for job_id {job_id}")
                 continue
-            result_len = len(results)
-            avg_record_size = (
-                sys.getsizeof(results[0])
-                if (avg_record_size == 0 and results)
-                else avg_record_size
-            )
-            for idx, result in enumerate(results):
+            counter = 0
+            for result in results:
                 self.jobs[job_id]["downloaded"] = True
                 result_array.append(result)
-                current_size += avg_record_size
-                if current_size >= self.file_size_limit or idx == (result_len - 1):
-                    yield {"start_page": idx, "data": result_array}
+                current_size += sys.getsizeof(result)
+                if current_size >= self.file_size_limit:
+                    yield {"start_page": counter, "data": result_array}
                     result_array = []
                     current_size = 0
+                counter += 1
+
+            if result_array:
+                yield {"start_page": counter, "data": result_array}
 
 
 class BulkEndpointHandler(BulkAPICaller):
